@@ -10,18 +10,19 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Test::Compile; # git description: v2.052-13-gf111d1b
+package Dist::Zilla::Plugin::Test::Compile; # git description: v2.053-8-g6cedd05
 # ABSTRACT: Common tests to check syntax of your modules, only using core modules
 # KEYWORDS: plugin test compile verify validate load modules scripts
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '2.053';
+our $VERSION = '2.054';
 
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
 use Data::Section 0.004 # fixed header_re
     { installer => method_installer }, '-setup';
+use Dist::Zilla::Dist::Builder ();
 
 with (
     'Dist::Zilla::Role::FileGatherer',
@@ -35,7 +36,11 @@ with (
     'Dist::Zilla::Role::FileFinderUser' => {
         method          => 'found_script_files',
         finder_arg_names => [ 'script_finder' ],
-        default_finders => [ ':ExecFiles' ],
+        default_finders => [
+            eval { Dist::Zilla::Dist::Builder->VERSION('5.038'); 1 }
+                ? ':PerlExecFiles'
+                : ':ExecFiles'
+        ],
     },
     'Dist::Zilla::Role::PrereqSource',
 );
@@ -112,10 +117,11 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        module_finder => $self->module_finder,
-        script_finder => $self->script_finder,
-        skips => [ $self->skips ],
-        map { $_ => $self->$_ } qw(filename fake_home needs_display fail_on_warning bail_out_on_fail phase),
+        module_finder => [ sort @{ $self->module_finder } ],
+        script_finder => [ sort @{ $self->script_finder } ],
+        skips => [ sort $self->skips ],
+        (map { $_ => $self->$_ ? 1 : 0 } qw(fake_home needs_display bail_out_on_fail)),
+        (map { $_ => $self->$_ } qw(filename fail_on_warning bail_out_on_fail phase)),
     };
     return $config;
 };
@@ -332,8 +338,9 @@ __PACKAGE__->meta->make_immutable;
 #pod =for stopwords executables
 #pod
 #pod Just like C<module_finder>, but for finding scripts.  The default value is
-#pod C<:ExecFiles> (see also L<Dist::Zilla::Plugin::ExecDir>, to make sure these
-#pod files are properly marked as executables for the installer).
+#pod C<:PerlExecFiles> (when available; otherwise C<:ExecFiles>)
+#pod -- see also L<Dist::Zilla::Plugin::ExecDir>, to make sure these
+#pod files are properly marked as executables for the installer.
 #pod
 #pod =head2 C<xt_mode>
 #pod
@@ -358,7 +365,7 @@ Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.053
+version 2.054
 
 =head1 SYNOPSIS
 
@@ -476,8 +483,9 @@ L<[FileFinder::Filter]|Dist::Zilla::Plugin::FileFinder::Filter> plugins.
 =for stopwords executables
 
 Just like C<module_finder>, but for finding scripts.  The default value is
-C<:ExecFiles> (see also L<Dist::Zilla::Plugin::ExecDir>, to make sure these
-files are properly marked as executables for the installer).
+C<:PerlExecFiles> (when available; otherwise C<:ExecFiles>)
+-- see also L<Dist::Zilla::Plugin::ExecDir>, to make sure these
+files are properly marked as executables for the installer.
 
 =head2 C<xt_mode>
 
@@ -646,7 +654,7 @@ for my $lib (@module_files)
     is($?, 0, "$lib loaded ok");
 
     shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
-        and not eval { blib->VERSION('1.01') };
+        and not eval { require blib; blib->VERSION('1.01') };
 
     if (@_warnings)
     {
@@ -674,7 +682,7 @@ foreach my $file (@scripts)
     is($?, 0, "$file compiled ok");
 
     shift @_warnings if @_warnings and $_warnings[0] =~ /^Using .*\bblib/
-        and not eval { blib->VERSION('1.01') };
+        and not eval { require blib; blib->VERSION('1.01') };
 
     # in older perls, -c output is simply the file portion of the path being tested
     if (@_warnings = grep { !/\bsyntax OK$/ }
